collective.stripe
=================
This package provides basic integration with Stripe (http://www.stripe.com) for payment processing.  It does not provide a complete payment workflow, but instead provides the components to setup api keys, live vs test mode, currency, and to include the necessary javascript on relevant pages.
